﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;
using System.Threading;

namespace Suchen
{
    public partial class Form1 : Form, IPrintResult
    {
        Thread th=null;
        SearchThread st = null;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            tableLayoutPanel1.Dock = DockStyle.Fill;
            startdir.Text = System.Environment.CurrentDirectory;
        }

        private void bnSelectDir_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog dialog = new FolderBrowserDialog();
            dialog.Description = "Auswahl des Startverzeichnisses";
            dialog.SelectedPath = startdir.Text;
            DialogResult ret = dialog.ShowDialog(this);
            if (ret == DialogResult.OK)
            {
                startdir.Text=dialog.SelectedPath;
            }
        }

        private void Calc(SearchThread.SearchModi modi)
        {
            if (Directory.Exists(startdir.Text))
            {
                st = new SearchThread(this, startdir.Text, modi);
                //ThreadStart ts = new ThreadStart(st.run);
                //th = new Thread(ts);
                th = new Thread(st.run);
                th.Start();
            }
            else
            {
                MessageBox.Show("Das Startverzeichnis existiert nicht", "Fehler beim Starten",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Error,
                    MessageBoxDefaultButton.Button1);
            }
        }


        delegate void printFile_Thread(string file);

        public void printFile(string file)
        {
            if (editor.InvokeRequired)
            {
                printFile_Thread p = 
                    new printFile_Thread(printFile);
                this.Invoke(p, new Object[] { file });
            }
            else
            {
                editor.AppendText("Datei: " + file + "\r\n");
            }
        }

        delegate void printStatus_Thread(string dir);
        public void printStatus(string dir)
        {
            if (actualDir.InvokeRequired)
            {
                printStatus_Thread p =
                    new printStatus_Thread(printStatus);
                this.Invoke(p, new Object[] { dir });
            }
            else
            {
                actualDir.Text=dir;
            }
        }

        delegate void printResult_Thread();
        public void printResult()
        {
            if (actualDir.InvokeRequired)
            {
                printResult_Thread p =
                    new printResult_Thread(printResult);
                this.Invoke(p);
            }
            else
            {
                editor.Text = "Anzahl der Dateien: "
                    + st.anzFiles +
                    "\r\n\r\nSumme: " + best_KB(st.summe);
            }
        }


        String best_KB(long size)
        {
            double s;
            size = size / 1024;
            if (size < 1000.0)
            {
                return size.ToString("##0.###") + " KB";
            }
            else
            {
                // MB oder GB
                s = size;
                s /= 1024;
                if (s < 1000.0)
                {
                    return s.ToString("##0.###") + " MB";
                }
                else
                {
                    s = s / 1024.0;
                    return s.ToString("##0.###") + " GB";
                }
            }
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (th != null && th.IsAlive)
            {
                th.Abort();
            }
        }

        private void bnStop_Click(object sender, EventArgs e)
        {
            if (th != null && th.IsAlive)
            {
                th.Abort();
                th = null;
            }

        }

        private void mnClose_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void mnPictures_Click(object sender, EventArgs e)
        {
            Calc(SearchThread.SearchModi.Pictures);
        }

        private void mnMediaFiles_Click(object sender, EventArgs e)
        {
            Calc(SearchThread.SearchModi.Media);
        }

        private void mnAllFiles_Click(object sender, EventArgs e)
        {
            Calc(SearchThread.SearchModi.AllFiles);
        }

        private void mnProginfo_Click(object sender, EventArgs e)
        {
            ProgInfo dialog = new ProgInfo();
            dialog.ShowDialog();
        }
    }
}
